@@ -12,17 +12,22 @@ from .circuitsim_grader import CircuitSimGrader
 from .pylc3_grader import PyLC3Grader
 from .multi_command_grader import MultiCommandGrader
 from .python_module_grader import PythonModuleGrader
+from .lc3tools_grader import LC3ToolsGrader
+from .lc3tools_legacy_grader import LC3ToolsLegacyGrader
 
 __all__ = ['InvalidGraderConfigError', 'GraderInterface', 'Part',
            'ThreadedGrader', 'PromptGrader', 'OpenFileGrader', 'CommandGrader',
-           'LibcheckGrader', 'JUnitJSONGrader', 'JUnitXMLGrader',
-           'BitwiseJSONGrader', 'CircuitSimGrader', 'PyLC3Grader',
-           'MultiCommandGrader', 'PythonModuleGrader']
+           'LC3ToolsGrader', 'LC3ToolsLegacyGrader', 'LibcheckGrader',
+           'JUnitJSONGrader', 'JUnitXMLGrader', 'BitwiseJSONGrader',
+           'CircuitSimGrader', 'PyLC3Grader', 'MultiCommandGrader',
+           'PythonModuleGrader']
 
 _GRADERS = (
     PromptGrader,
     OpenFileGrader,
     CommandGrader,
+    LC3ToolsGrader,
+    LC3ToolsLegacyGrader,
     LibcheckGrader,
     JUnitJSONGrader,
     JUnitXMLGrader,
